@@ -133,8 +133,10 @@ struct user **up;
   *up = (struct user *)calloc(1, sizeof(struct user));
   if (!*up)
     return -1;		/* he still does not exist */
+#ifdef COPY_PASTE
   (*up)->u_copybuffer = NULL;
   (*up)->u_copylen = 0;
+#endif
   (*up)->u_Esc = DefaultEsc;
   (*up)->u_MetaEsc = DefaultMetaEsc;
   strncpy((*up)->u_name, name, 20);
@@ -256,11 +258,16 @@ struct user **up;
   AclSetPerm(u, default_c_bit[ACL_EXEC] ? "+x" : "-x", "?");
 #endif
   debug1("FREEING user structure for %s\n", u->u_name);
+#ifdef COPY_PASTE
   UserFreeCopyBuffer(u);
+#endif
   free((char *)u);
   return 0;
 }
 
+
+#ifdef COPY_PASTE
+
 /*
  * returns 0 if the copy buffer was really deleted.
  * Also removes any references into the users copybuffer
@@ -291,6 +298,8 @@ struct user *u;
   return 0;
 }
 
+#endif	/* COPY_PASTE */
+
 /************************************************************************
  *                     end of user managing code                        *
  ************************************************************************/
