@@ -359,6 +359,10 @@ FinitTerm()
       ResizeDisplay(D_defwidth, D_defheight);
       DefRestore();
       SetAttrFont(0, ASCII);
+#ifdef MAPKEYS
+      PutStr(D_KE);
+      PutStr(D_CCE);
+#endif
       if (D_hstatus)
 	PutStr(D_DS);
       D_x = D_y = -1;
