@@ -50,6 +50,7 @@ extern void  MakeNewEnv __P((void));
 /* ansi.c */
 extern void  Activate __P((int));
 extern void  ResetWindow __P((struct win *));
+extern void  ResetCharsets __P((struct win *));
 extern void  WriteString __P((struct win *, char *, int));
 extern void  NewAutoFlow __P((struct win *, int));
 extern void  Redisplay __P((int));
@@ -109,6 +110,7 @@ extern void  display_bindkey __P((char *, struct action *));
 
 /* window.c */
 extern int   MakeWindow __P((struct NewWindow *));
+extern int   RemakeWindow __P((struct win *));
 extern void  FreeWindow __P((struct win *));
 #ifdef PSEUDOS
 extern int   winexec __P((char **));
