@@ -102,6 +102,11 @@ int mode;
   int maxlen;
   struct inpdata *inpdata;
   
+  if (!display)
+    {
+      Msg(0, "Input: cannot interact with user w/o display. Try other form of command\n");
+      return;
+    }
   if (len > 100)
     len = 100;
   if (!(mode & INP_NOECHO))
