@@ -177,12 +177,22 @@
  *                     Use \r (not \n) to join lines in pastebuf.
  *                     bindkey can now remove sequences.
  *                     InitTTY fixed for PLAIN. -- DISTRIBUTED
- *                     
+ * 04.04.95 -- 3.06.02 Simple ESC-CR fix in the vt100 state machine.
+ *                     Now compiles again with all extras disabled.
+ *                     Zombie resurrect added. defc1, defgr, defkanji
+ *                     added. Screen now replies to a secondary DA
+ *                     query. Some missing NEED_XXX added in comm.c.
+ *                     Better default tty permissions/group test.
+ *                     More AUX support, now compiles with POSIX.
+ *                     Function keycodes xtermified (F11, F12).
+ *                     Paste bug fixed (only worked with KANJI).
+ *                     Check bcopy before memcpy/memmove.
+ *                     FindSocket code much fixed & improved.
  */
 
 #define ORIGIN "FAU"
 #define REV 3
 #define VERS 6
-#define PATCHLEVEL 1
-#define DATE "16-Jan-95"
+#define PATCHLEVEL 2
+#define DATE "4-Apr-95"
 #define STATE "" 
